UITest_sw_{navigator,findBar,classification,chart}: enable oneprocess mode

Execution time changes:

- from 2m5,297s to 1m28,636s
- from 20,711s to 14,122s
- from 18,361s to 14,835s
- from 15,874s to 14,810s

for me.

See tdf#154451 for motivation.

Change-Id: I7d5735f9b900568c7f7aa61ce7be5e622bd9fc38
Reviewed-on: https://gerrit.libreoffice.org/c/core/+/150253
Reviewed-by: Miklos Vajna <vmiklos@collabora.com>
Tested-by: Jenkins
This commit is contained in:
Miklos Vajna
2023-04-12 09:11:19 +02:00
parent 4c288a18e7
commit 31b365d1fe
4 changed files with 16 additions and 0 deletions
+4
View File
@@ -14,3 +14,7 @@ $(eval $(call gb_UITest_add_modules,classification,$(SRCDIR)/sw/qa/uitest,\
$(eval $(call gb_UITest_set_defs,classification, \
TDOC="$(SRCDIR)/sw/qa/uitest/data" \
))
$(eval $(call gb_UITest_use_oneprocess,classification))
# vim: set noet sw=4 ts=4:
+4
View File
@@ -10,3 +10,7 @@ $(eval $(call gb_UITest_UITest,sw_chart))
$(eval $(call gb_UITest_add_modules,sw_chart,$(SRCDIR)/sw/qa/uitest,\
chart/ \
))
$(eval $(call gb_UITest_use_oneprocess,sw_chart))
# vim: set noet sw=4 ts=4:
+4
View File
@@ -14,3 +14,7 @@ $(eval $(call gb_UITest_add_modules,sw_findBar,$(SRCDIR)/sw/qa/uitest,\
$(eval $(call gb_UITest_set_defs,sw_findBar, \
TDOC="$(SRCDIR)/sw/qa/uitest/data" \
))
$(eval $(call gb_UITest_use_oneprocess,sw_findBar))
# vim: set noet sw=4 ts=4:
+4
View File
@@ -14,3 +14,7 @@ $(eval $(call gb_UITest_add_modules,sw_navigator,$(SRCDIR)/sw/qa/uitest,\
$(eval $(call gb_UITest_set_defs,sw_navigator, \
TDOC="$(SRCDIR)/sw/qa/uitest/data" \
))
$(eval $(call gb_UITest_use_oneprocess,sw_navigator))
# vim: set noet sw=4 ts=4: